@@ -624,7 +624,7 @@ class ApiGroup(object):
         self.apis.append(api)
 
 class ApiModel(object):
-    def __init__(self, root, preifx, version, groups, apiServer='', srvVersion='', title='', description=''):
+    def __init__(self, root, preifx, version, groups, apiServer='', srvVersion='', title='', description='', authmap={}):
         self.root = root
         self.prefix = preifx
         self.version = version
@@ -634,6 +634,7 @@ class ApiModel(object):
         self.description = description
         self.apiServer = apiServer
         self.srvVersion = srvVersion
+        self.authmap = authmap
 
     def __repr__(self):
         txt = 'root %s %s\n' % (self.prefix, self.version)
@@ -833,6 +834,7 @@ class ApiModel(object):
         description = ''
         apiServer = ''
         srvVersion = ''
+        authmap = {}
 
         for line in lines[1:]:
             lineno += 1
@@ -842,16 +844,22 @@ class ApiModel(object):
 
             # config
             if line.startswith('- title:'):
-                title = line.lstrip('- title:').strip()
+                title = line.replace('- title:', '').strip()
                 continue
             if line.startswith('- description:'):
-                description = line.lstrip('- description:').strip()
+                description = line.replace('- description:', '').strip()
                 continue
             if line.startswith('- apiserver:'):
-                apiServer = line.lstrip('- apiserver:').strip()
+                apiServer = line.replace('- apiserver:', '').strip()
                 continue
             if line.startswith('- version:'):
-                srvVersion = line.lstrip('- version:').strip()
+                srvVersion = line.replace('- version:', '').strip()
+                continue
+            if line.startswith('- authmap:'):
+                line = line.replace('- authmap:', '')
+                for item in line.split(','):
+                    kv = item.split('=')
+                    authmap[kv[0].strip()] = kv[1].strip()
                 continue
             
             width = len(line) - len(line.lstrip())
@@ -930,7 +938,7 @@ class ApiModel(object):
                             currentNestParam.append(param)
                     nestParam.addChildren(param)
 
-        return cls(root, PREFIX, VERSION, groups, apiServer, srvVersion, description)
+        return cls(root, PREFIX, VERSION, groups, apiServer, srvVersion, description, authmap)
 
 class GoFunc(object):
     def __init__(self, name):
