@@ -41,11 +41,12 @@ vlogs = {
     '0.3.8': 'add wildcard router',
     '0.3.9': 'add swagger codegen',
     '0.4.0': 'add swagger security, json resp model',
-    '0.4.1': 'add m2c init from git repo'
+    '0.4.1': 'add m2c init from git repo',
+    '0.4.2': 'fix pack'
 }
 
 name = 'm2c'
-version = '0.4.1'
+version = '0.4.2'
 
 from .conf import M2C_PATH, Color
 from .helper import m2c_version
